==> deepin-deb-installer_1.2.4.orig.tar.gz: deepin-deb-installer-1.2.4/translations/deepin-deb-installer_da.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="da" version="2.1">
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../debinstaller.cpp" line="74"/>
        <source>Deepin Package Manager</source>
        <translation>Deepin pakkehåndtering</translation>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="239"/>
        <source>Bulk Install</source>
        <translation>Masseinstallation</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../deblistmodel.cpp" line="57"/>
        <source>Installation failed, please check your network connection</source>
        <translation>Installation mislykkedes, tjek venligst din netværksforbindelse</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="59"/>
        <source>Installation failed, please check updates in Control Center</source>
        <translation>Installation mislykkedes, tjek venligst opdateringer i kontrolcenter</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="61"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Installation mislykkedes, utilstrækkelig diskplads</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="64"/>
        <source>Installation Failed</source>
        <translation>Installation mislykkedes</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="296"/>
        <location filename="../deblistmodel.cpp" line="303"/>
        <source>Broken Dependencies: %1</source>
        <translation>Ødelagte afhængigheder: %1</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="299"/>
        <source>Unmatched package architecture</source>
        <translation>Ikke-matchet pakkearkitektur</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../filechoosewidget.cpp" line="53"/>
        <source>Drag and drop file here</source>
        <translation>Træk-og-slip filer her</translation>
    </message>
    <message>
        <location filename="../filechoosewidget.cpp" line="80"/>
        <source>Select File</source>
        <translation>Vælg fil</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Collapse</source>
        <translation>Sammenfold</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Display details</source>
        <translation>Vis detaljer</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="58"/>
        <source>Install</source>
        <translation>Installer</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="59"/>
        <source>Done</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="61"/>
        <source>Back</source>
        <translation>Tilbage</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../packageslistdelegate.cpp" line="102"/>
        <source>Installing</source>
        <translation>Installerer</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="106"/>
        <source>Installed</source>
        <translation>Installeret</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="110"/>
        <source>Failed</source>
        <translation>Mislykkedes</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="135"/>
        <source>Same version installed</source>
        <translation>Samme version installeret</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="138"/>
        <source>Other version installed: %1</source>
        <translation>Anden version installeret: %1</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../singleinstallpage.cpp" line="82"/>
        <source>Collapse</source>
        <translation>Sammenfold</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="82"/>
        <source>Display details</source>
        <translation>Vis detaljer</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="113"/>
        <source>Install</source>
        <translation>Installer</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="115"/>
        <source>Remove</source>
        <translation>Fjern</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="117"/>
        <source>Reinstall</source>
        <translation>Geninstaller</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="119"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="121"/>
        <source>Back</source>
        <translation>Tilbage</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="123"/>
        <source>Done</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="138"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="296"/>
        <source>Installed successfully</source>
        <translation>Installeret</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="298"/>
        <source>Uninstalled successfully</source>
        <translation>Afinstalleret</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="366"/>
        <source>Other version installed: %1</source>
        <translation>Anden version installeret: %1</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="309"/>
        <source>Uninstall Failed</source>
        <translation>Afinstallation mislykkedes</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="131"/>
        <source>Name: </source>
        <translation>Navn:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="364"/>
        <source>Same version installed</source>
        <translation>Samme version installeret</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Display related packages</source>
        <translation>Vis relaterede pakker</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Collapse</source>
        <translation>Sammenfold</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="46"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="48"/>
        <source>Confirm</source>
        <translation>Bekræft</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="101"/>
        <source>Are you sure to uninstall %1?
All dependencies will also be removed</source>
        <translation>Er du sikker på, at du vil afinstallere %1?
Alle afhængigheder vil også blive fjernet</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Deepin Package Manager</source>
        <translation>Deepin pakkehåndtering</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Deepin Package Manager is an application used to help users install and remove local software, supports bulk install.</source>
        <translation>Deepin pakkehåndtering er et program som hjælper brugere med at installere og fjerne lokal software og som understøtter masseinstallation.</translation>
    </message>
</context>
</TS>

==> deepin-deb-installer_1.2.5.orig.tar.gz: deepin-deb-installer-1.2.5/translations/deepin-deb-installer_da.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="da" version="2.1">
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../debinstaller.cpp" line="74"/>
        <source>Deepin Package Manager</source>
        <translation>Deepin pakkehåndtering</translation>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="239"/>
        <source>Bulk Install</source>
        <translation>Masseinstallation</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../deblistmodel.cpp" line="57"/>
        <source>Installation failed, please check your network connection</source>
        <translation>Installation mislykkedes, tjek venligst din netværksforbindelse</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="59"/>
        <source>Installation failed, please check updates in Control Center</source>
        <translation>Installation mislykkedes, tjek venligst opdateringer i kontrolcenter</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="61"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Installation mislykkedes, utilstrækkelig diskplads</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="64"/>
        <source>Installation Failed</source>
        <translation>Installation mislykkedes</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="296"/>
        <location filename="../deblistmodel.cpp" line="303"/>
        <source>Broken Dependencies: %1</source>
        <translation>Ødelagte afhængigheder: %1</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="299"/>
        <source>Unmatched package architecture</source>
        <translation>Ikke-matchet pakkearkitektur</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../filechoosewidget.cpp" line="53"/>
        <source>Drag and drop file here</source>
        <translation>Træk-og-slip filer her</translation>
    </message>
    <message>
        <location filename="../filechoosewidget.cpp" line="80"/>
        <source>Select File</source>
        <translation>Vælg fil</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Collapse</source>
        <translation>Sammenfold</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Display details</source>
        <translation>Vis detaljer</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="58"/>
        <source>Install</source>
        <translation>Installer</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="59"/>
        <source>Done</source>
        <translation>Færdig</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="61"/>
        <source>Back</source>
        <translation>Tilbage</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../packageslistdelegate.cpp" line="102"/>
        <source>Installing</source>
        <translation>Installerer</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="106"/>
        <source>Installed</source>
        <translation>Installeret</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="110"/>
        <source>Failed</source>
        <translation>Mislykkedes</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="135"/>
        <source>Same version installed</source>
        <translation>Samme version installeret</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="138"/>
        <source>Other version installed: %1</source>
        <translation>Anden version installeret: %1</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../singleinstallpage.cpp" line="82"/>
        <source>Collapse</source>
        <translation>Sammenfold</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="82"/>
        <source>Display details</source>
        <translation>Vis detaljer</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="113"/>
        <source>Install</source>
        <translation>Installer</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="115"/>
        <source>Remove</source>
        <translation>Fjern</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="117"/>
        <source>Reinstall</source>
        <translation>Geninstaller</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="119"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="121"/>
        <source>Back</source>
        <translation>Tilbage</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="123"/>
        <source>Done</source>
        <translation>Færdig</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="138"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="296"/>
        <source>Installed successfully</source>
        <translation>Installeret</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="298"/>
        <source>Uninstalled successfully</source>
        <translation>Afinstalleret</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="366"/>
        <source>Other version installed: %1</source>
        <translation>Anden version installeret: %1</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="309"/>
        <source>Uninstall Failed</source>
        <translation>Afinstallation mislykkedes</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="131"/>
        <source>Name: </source>
        <translation>Navn:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="364"/>
        <source>Same version installed</source>
        <translation>Samme version installeret</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Display related packages</source>
        <translation>Vis relaterede pakker</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Collapse</source>
        <translation>Sammenfold</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="46"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="48"/>
        <source>Confirm</source>
        <translation>Bekræft</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="101"/>
        <source>Are you sure to uninstall %1?
All dependencies will also be removed</source>
        <translation>Er du sikker på, at du vil afinstallere %1?
Alle afhængigheder vil også blive fjernet</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Deepin Package Manager</source>
        <translation>Deepin pakkehåndtering</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Deepin Package Manager is an application used to help users install and remove local software, supports bulk install.</source>
        <translation>Deepin pakkehåndtering er et program som hjælper brugere med at installere og fjerne lokal software og som understøtter masseinstallation.</translation>
    </message>
</context>
</TS>
